package com.ruoyi.cs.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.cs.domain.CsMessageRecord;

/**
 * 短信通知记录Service接口
 *
 * @author ruoyi
 * @date 2024-05-29
 */
public interface ICsMessageRecordService
{
    /**
     * 查询短信通知记录
     *
     * @param messageRecordId 短信通知记录主键
     * @return 短信通知记录
     */
    public CsMessageRecord selectCsMessageRecordByMessageRecordId(String messageRecordId);

    /**
     * 查询短信通知记录列表
     *
     * @param csMessageRecord 短信通知记录
     * @return 短信通知记录集合
     */
    public List<CsMessageRecord> selectCsMessageRecordList(CsMessageRecord csMessageRecord);

    /**
     * 新增短信通知记录
     *
     * @param csMessageRecord 短信通知记录
     * @return 结果
     */
    public int insertCsMessageRecord(CsMessageRecord csMessageRecord);

    /**
     * 修改短信通知记录
     *
     * @param csMessageRecord 短信通知记录
     * @return 结果
     */
    public int updateCsMessageRecord(CsMessageRecord csMessageRecord);

    /**
     * 批量删除短信通知记录
     *
     * @param messageRecordIds 需要删除的短信通知记录主键集合
     * @return 结果
     */
    public int deleteCsMessageRecordByMessageRecordIds(String[] messageRecordIds);

    /**
     * 删除短信通知记录信息
     *
     * @param messageRecordId 短信通知记录主键
     * @return 结果
     */
    public int deleteCsMessageRecordByMessageRecordId(String messageRecordId);

    /**
     * 批量发送短信
     *
     * @param csMessageRecord 短信通知记录
     * @return 结果
     */
    public AjaxResult bachSendMessage(CsMessageRecord csMessageRecord);
}
